@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2013 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2015 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -36,12 +36,8 @@
 #ifndef _LOGGER_H
 #define _LOGGER_H
 
-#ifdef MACOSX
- #ifndef wcscasecmp
-extern inline int wcscasecmp(const wchar_t* s1, const wchar_t* s2);
-  #define MACOSX_ECSCASECMP
- #endif
-#endif
+/* If defined, output debug information about console output. */
+/*#define DEBUG_CONSOLE_OUTPUT*/
 
 #ifdef _DEBUG
  #define _DEBUG_QUEUE
@@ -51,10 +47,10 @@ extern inline int wcscasecmp(const wchar_t* s1, const wchar_t* s2);
  #include <windows.h>
  #define LOG_USER    (1<<3)
 #endif
-#include "wrapper_i18n.h"
 #ifndef DWORD
  #define DWORD unsigned long
 #endif
+#include "logger_base.h"
 
 /* * * Log source constants * * */
 
@@ -87,38 +83,6 @@ extern inline int wcscasecmp(const wchar_t* s1, const wchar_t* s2);
 #define LOG_FORMAT_LOGFILE_DEFAULT TEXT("LPTM")
 #define LOG_FORMAT_CONSOLE_DEFAULT TEXT("PM")
 
-/* * * Log level constants * * */
-
-/* No logging at all. */
-#define LEVEL_NONE   9
-
-/* Notice messages which should always be displayed.  These never go to the syslog. */
-#define LEVEL_NOTICE 8
-
-/* Advisor messages which should always be displayed.  These never go to the syslog. */
-#define LEVEL_ADVICE 7
-
-/* Too many restarts, unable to start etc. Case when the Wrapper is forced to exit. */
-#define LEVEL_FATAL  6
-
-/* JVM died, hung messages */
-#define LEVEL_ERROR  5
-
-/* Warning messages. */
-#define LEVEL_WARN   4
-
-/* Started, Stopped, Restarted messages. */
-#define LEVEL_STATUS 3
-
-/* Copyright message. and logged console output. */
-#define LEVEL_INFO   2
-
-/* Current debug messages */
-#define LEVEL_DEBUG  1
-
-/* Unknown level */
-#define LEVEL_UNKNOWN  0
-
 /* * * Log file roll mode constants * * */
 #define ROLL_MODE_UNKNOWN         0
 #define ROLL_MODE_NONE            1
@@ -132,13 +96,6 @@ extern inline int wcscasecmp(const wchar_t* s1, const wchar_t* s2);
 #define ROLL_MODE_DATE_TOKEN      TEXT("YYYYMMDD")
 
 
-#ifdef WIN32
-extern void setConsoleStdoutHandle(HANDLE stdoutHandle);
-#endif
-
-/* * * Function predeclaration * * */
-#define strcmpIgnoreCase(str1, str2) _tcsicmp(str1, str2)
-
 
 /* This can be called from within logging code that would otherwise get stuck in recursion.
  *  Log to the console exactly when it happens and then also try to get it into the log
@@ -177,6 +134,13 @@ extern void setSilentLogLevels();
  */
 extern void setSimpleLogLevels();
 
+#ifdef WIN32
+/**
+ * This sets a flag which tells the logger that alternate source labels should be used to indicate that the current process is a launcher.
+ */
+extern void setLauncherSource();
+#endif
+
 /**
  * Used for testing to set a pause into the next log entry made.
  *
@@ -184,6 +148,13 @@ extern void setSimpleLogLevels();
  */
 extern void setPauseTime(int pauseTime);
 
+/**
+ * Set to true to cause changes in internal buffer sizes to be logged.  Useful for debugging.
+ *
+ * @param log TRUE if changes should be logged.
+ */
+void setLogBufferGrowth(int log);
+
 /* * Logfile functions * */
 extern int isLogfileAccessed();
 
@@ -245,8 +216,17 @@ extern void setLogfileMaxLogFiles(int max_log_files);
 extern void setLogfilePurgePattern(const TCHAR *pattern);
 extern void setLogfilePurgeSortMode(int sortMode);
 extern DWORD getLogfileActivity();
-extern void closeLogfile();
+
+/** Sets the auto flush log file flag. */
+extern void setLogfileAutoFlush(int autoFlush);
+
+/** Sets the auto close log file flag. */
 extern void setLogfileAutoClose(int autoClose);
+
+/** Closes the logfile if it is open. */
+extern void closeLogfile();
+
+/** Flushes any buffered logfile output to the disk. */
 extern void flushLogfile();
 
 /* * Console functions * */
@@ -255,6 +235,9 @@ extern void setConsoleLogLevelInt(int console_log_level);
 extern int getConsoleLogLevelInt();
 extern void setConsoleLogLevel( const TCHAR *console_log_level );
 extern void setConsoleFlush(int flush);
+#ifdef WIN32
+extern void setConsoleDirect(int direct);
+#endif
 extern void setConsoleFatalToStdErr(int toStdErr);
 extern void setConsoleErrorToStdErr(int toStdErr);
 extern void setConsoleWarnToStdErr(int toStdErr);
@@ -263,18 +246,23 @@ extern void setConsoleWarnToStdErr(int toStdErr);
 extern void setSyslogLevelInt(int loginfo_level);
 extern int getSyslogLevelInt();
 extern void setSyslogLevel( const TCHAR *loginfo_level );
+extern void setSyslogSplitMessages(int splitMessages);
 #ifndef WIN32
 extern void setSyslogFacility( const TCHAR *loginfo_level );
 #endif
 extern void setSyslogEventSourceName( const TCHAR *event_source_name );
-extern int registerSyslogMessageFile();
+extern void setWarnSyslogUnregistered(int value);
+extern int syslogMessageFileRegistered();
+extern int registerSyslogMessageFile(int forceInstall);
 extern int unregisterSyslogMessageFile();
 
 
+extern void resetDuration();
+
 extern int getLowLogLevel();
 
 /* * General log functions * */
-extern int initLogging();
+extern int initLogging(void (*logFileChanged)(const TCHAR *logFile));
 extern int disposeLogging();
 extern void setUptime(int uptime, int flipped);
 extern void rollLogs();
@@ -305,8 +293,6 @@ extern void log_printf( int source_id, int level, const TCHAR *lpszFmt, ... );
  */
 extern void log_printf_queue( int useQueue, int source_id, int level, const TCHAR *lpszFmt, ... );
 
-extern TCHAR* getLastErrorText();
-extern int getLastError();
 extern void maintainLogger();
 extern void invalidMultiByteSequence(const TCHAR *context, int id);
 #endif
